@@ -87,6 +87,14 @@ from doing.utils import get_config
     help="The name of the branch to branch from and to. It overrides the repository's default branch.",
     show_envvar=True,
 )
+@click.option(
+    "--branch-prefix",
+    required=False,
+    default="",
+    type=str,
+    help='The prefix to be prepended to the branch name. Defaults to ""',
+    show_envvar=True,
+)
 def workon(
     issue,
     type,
@@ -99,6 +107,7 @@ def workon(
     delete_source_branch: bool,
     story_points,
     default_branch,
+    branch_prefix: str,
 ):
     """
     Create issue with PR and switch git branch.
@@ -134,5 +143,6 @@ def workon(
         checkout=checkout,
         delete_source_branch=delete_source_branch,
         default_branch=default_branch,
+        branch_prefix=branch_prefix,
         **get_common_options(),
     )
